@@ -1,19 +1,7 @@
-/* This file is part of KDevelop
-    Copyright 2008 Niko Sams <niko.sams@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2008 Niko Sams <niko.sams@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef TESTEXPRESSIONPARSER_H
@@ -31,6 +19,7 @@ public:
     TestExpressionParser();
 
 private slots:
+    void newClass_data();
     void newClass();
     void newSelf();
     void newStatic();
@@ -44,12 +33,15 @@ private slots:
     void invalidTraitUse();
     void namespaceUseNameConflict();
     void globalFunction();
+    void globalFunctionCall_data();
+    void globalFunctionCall();
     void chainCall();
     void thisObject();
     void integralTypes();
     void newObject();
     void cast();
     void operations();
+    void findArg_data();
     void findArg();
     void array_data();
     void array();
@@ -65,6 +57,11 @@ private slots:
     void invalidVariadicFunction_data();
     void invalidVariadicFunction();
     void invalidArgumentUnpacking();
+    void closure_data();
+    void closure();
+    void closureUse_data();
+    void closureUse();
+    void closureInvalidUse();
 };
 
 }
